@@ -13,10 +13,14 @@
 #include "mtools.h"
 #include "devices.h"
 
-#define DEF_ARG1 0, 0x2,0,0, 0, 0, 0
+#define DEF_ARG1 0, 0, 0x2,0,0, 0, 0, 0
 #define DEF_ARG0 0,0,0,DEF_ARG1
 #define DEF_ARG 0L,DEF_ARG0
 
+#define VOLD_DEF_ARG1 1, 0, 0x2,0,0, 0, 0, 0
+#define VOLD_DEF_ARG0 0,0,0,DEF_ARG1
+#define VOLD_DEF_ARG 0L,DEF_ARG0
+
 #define ED312	12,0,80,2,36,DEF_ARG /* 3 1/2 extra density */
 #define HD312	12,0,80,2,18,DEF_ARG /* 3 1/2 high density */
 #define DD312	12,0,80,2, 9,DEF_ARG /* 3 1/2 double density */
@@ -27,6 +31,7 @@
 #define SSsmall	12,0,40,1, 8,DEF_ARG /* 5 1/4 single sided DD, (160k) */
 #define GENHD	16,0, 0,0, 0,DEF_ARG /* Generic 16 bit FAT fs */
 #define GENFD	12,0, 0,0, 0,DEF_ARG /* Generic 12 bit FAT fs */
+#define VOLDFD	12,0, 0,0, 0,VOLD_DEF_ARG /* Generic 12 bit FAT fs with vold */
 #define GEN    	 0,0, 0,0, 0,DEF_ARG /* Generic fs of any FAT bits */
 #define ZIPJAZ(x)	 0,x, 0,0, 0,0L,4,0,0,DEF_ARG1 /* Zip or Jaz disks */
 #define RZIPJAZ(x)	 0,x, 0,0, 0,0L,4,1,1,DEF_ARG1 /* Zip or Jaz disks */
@@ -43,7 +48,18 @@ static int compare_geom(struct device *dev, struct device *orig_dev)
 #define devices const_devices
 
 
-#ifdef lynxos
+#ifdef OS_aux
+#define predefined_devices
+struct device devices[] = {
+   {"/dev/floppy0", 'A', GENFD },
+   {"/dev/rdsk/c104d0s31", 'J', ZIPJAZ(O_EXCL) },
+   {"/dev/rdsk/c105d0s31", 'Z', ZIPJAZ(O_EXCL) }
+};
+#define INIT_NOOP
+#endif /* aux */
+
+
+#ifdef OS_lynxos
 #define predefined_devices
 struct device devices[] = {
 	{"/dev/fd1440.0", 	'A', HD312 },
@@ -55,19 +71,19 @@ struct device devices[] = {
 #ifdef __BEOS__
 #define predefined_devices
 struct device devices[] = {
-	{"/dev/floppy_disk", 	'A', HD312 },
+	{"/dev/disk/floppy/raw", 	'A', HD312 },
 };
 #define INIT_NOOP
 #endif /* BEBOX */
 
 
-#ifdef hpux
+#ifdef OS_hpux
 #include <sys/floppy.h>
 #undef SSIZE
 
 #define predefined_devices
 struct device devices[] = {
-#ifdef hpux10
+#ifdef OS_hpux10
 /* hpux10 uses different device names according to Frank Maritato
  * <frank@math.hmc.edu> */
 	{"/dev/floppy/c0t0d0",		'A', HD312 },
@@ -81,10 +97,12 @@ struct device devices[] = {
  	{"/dev/rfloppy/c20Ad1s0",	'B', HD312 },
  	{"/dev/rscsi",			'C', GENHD },
 #endif
-	{"/dev/rdsk/c201d5",		'D', ZIPJAZ(O_EXCL) },
-	{"/dev/rdsk/c201d5s0",		'D', ZIPJAZ(O_EXCL) },
+	{"/dev/rdsk/c201d4",		'J', ZIPJAZ(O_EXCL) },
+	{"/dev/rdsk/c201d4s0",		'J', ZIPJAZ(O_EXCL) },
+	{"/dev/rdsk/c201d5",		'Z', ZIPJAZ(O_EXCL) },
+	{"/dev/rdsk/c201d5s0",		'Z', ZIPJAZ(O_EXCL) },
 };
-#ifdef hpux9
+#ifdef OS_hpux9
 /* geometry setting ioctl's contributed by Paolo Zeppegno
  * <paolo@to.sem.it>, may cause "Not a typewriter" messages on other
  * versions according to support@vital.com */
@@ -131,27 +149,27 @@ static inline int set_parameters(int fd, struct generic_floppy_struct *floppy,
 #endif /* hpux */
  
 
-#if (defined(sinix) || defined(sni) || defined(SNI))
+#if (defined(OS_sinix) || defined(VENDOR_sni) || defined(SNI))
 #define predefined_devices
 struct device devices[] = {
-#ifdef mips     /* for Siemens Nixdorf's  SINIX-N/O (mips) 5.4x SVR4 */
+#ifdef CPU_mips     /* for Siemens Nixdorf's  SINIX-N/O (mips) 5.4x SVR4 */
 	{ "/dev/at/flp/f0t",    'A', HD312},
 	{ "/dev/fd0",           'A', GENFD},
 #else
-#ifdef i386     /* for Siemens Nixdorf's  SINIX-D/L (intel) 5.4x SVR4 */
+#ifdef CPU_i386     /* for Siemens Nixdorf's  SINIX-D/L (intel) 5.4x SVR4 */
 	{ "/dev/fd0135ds18",	'A', HD312},
 	{ "/dev/fd0135ds9",	'A', DD312},
 	{ "/dev/fd0",		'A', GENFD},
 	{ "/dev/fd1135ds15",	'B', HD514},
 	{ "/dev/fd1135ds9",	'B', DD514},
 	{ "/dev/fd1",		'B', GENFD},
-#endif /*i386*/
+#endif /* CPU_i386 */
 #endif /*mips*/
 };
 #define INIT_NOOP
 #endif
 
-#ifdef ultrix
+#ifdef OS_ultrix
 #define predefined_devices
 struct device devices[] = {
 	{"/dev/rfd0a",		'A', GENFD}, /* guessed */
@@ -162,9 +180,9 @@ struct device devices[] = {
 #endif
 
 
-#ifdef isc
+#ifdef OS_isc
 #define predefined_devices
-#if (defined(isc2) && defined(OLDSTUFF))
+#if (defined(OS_isc2) && defined(OLDSTUFF))
 struct device devices[] = {
 	{"/dev/rdsk/f0d9dt",   	'A', DD514},
 	{"/dev/rdsk/f0q15dt",	'A', HD514},
@@ -224,15 +242,15 @@ static int set_parameters(int fd, struct generic_floppy_struct *floppy,
 #endif
 #endif /* isc */
 
-#ifdef i370
+#ifdef CPU_i370
 #define predefined_devices
 struct device devices[] = {
 	{"/dev/rfd0", 'A', GENFD},
 };
 #define INIT_NOOP
-#endif /* i370 */
+#endif /* CPU_i370 */
 
-#ifdef aix
+#ifdef OS_aix
 /* modified by Federico Bianchi */
 #define predefined_devices
 struct device devices[] = {
@@ -242,41 +260,125 @@ struct device devices[] = {
 #endif /* aix */
 
   
-#ifdef osf4
+#ifdef OS_osf4
 /* modified by Chris Samuel <chris@rivers.dra.hmg.gb> */
 #define predefined_devices
 struct device devices[] = {
   {"/dev/fd0c",'A',GENFD},
 };
 #define INIT_NOOP
-#endif /* osf4 */
+#endif /* OS_osf4 */
+
+
+#ifdef OS_solaris
+
+#ifdef USING_NEW_VOLD
+
+char *alias_name = NULL;
+  
+extern char *media_oldaliases(char *);
+extern char *media_findname(char *);
+
+char *getVoldName(struct device *dev, char *name)
+{
+	char *rname;
+  
+	if(!dev->vold)
+		return name;
+	
+	/***
+	 * Solaris specific routines to use the volume management
+	 * daemon and libraries to get the correct device name...
+	 ***/
+	rname = media_findname(name);
+	if (rname == NULL) {
+		if ((alias_name = media_oldaliases(name)) != NULL)
+			rname = media_findname(alias_name);
+		if (rname == NULL) {
+			fprintf(stderr, 
+				"No such volume or no media in device: %s.\n", 
+				name);
+			exit(1);
+		}
+	}
+	return rname;
+}
+#endif /* USING_NEW_VOLD */
 
-#ifdef solaris
 #define predefined_devices
 struct device devices[] = {
-#ifdef	USING_VOLD
+#ifdef  USING_NEW_VOLD
+	{"floppy", 'A', VOLDFD },
+#elif	USING_VOLD
 	{"/vol/dev/aliases/floppy0", 'A', GENFD},
 	{"/dev/rdiskette", 'B', GENFD},
 #else	/* ! USING_VOLD */
 	{"/dev/rdiskette", 'A', GENFD},
 	{"/vol/dev/aliases/floppy0", 'B', GENFD},
-
 #endif	/* USING_VOLD */
-	{"/dev/rdsk/c0t5d0s2", 'D', RZIPJAZ(O_NDELAY)},
+	{"/dev/rdsk/c0t4d0s2", 'J', RZIPJAZ(O_NDELAY)},
+	{"/dev/rdsk/c0t5d0s2", 'Z', RZIPJAZ(O_NDELAY)},
 };
-#define INIT_NOOP
+
+
+
+/*
+ * Ofer Licht <ofer@stat.Berkeley.EDU>, May 14, 1997.
+ */
+
+#define INIT_GENERIC
+
+#include <sys/fdio.h>
+#include <sys/mkdev.h>	/* for major() */
+
+struct generic_floppy_struct
+{
+  struct fd_char fdchar;
+};
+
+#define BLOCK_MAJOR 36
+#define CHAR_MAJOR 36
+
+static inline int get_parameters(int fd, struct generic_floppy_struct *floppy)
+{
+	if (ioctl(fd, FDIOGCHAR, &(floppy->fdchar)) != 0) {
+		perror("");
+		ioctl(fd, FDEJECT, NULL);
+		return(1);
+	}
+	return 0;
+}
+
+#define TRACKS(floppy) floppy.fdchar.fdc_ncyl
+#define HEADS(floppy) floppy.fdchar.fdc_nhead
+#define SECTORS(floppy) floppy.fdchar.fdc_secptrack
+/* SECTORS_PER_DISK(floppy) not used */
+#define FD_SECTSIZE(floppy) floppy.fdchar.fdc_sec_size
+#define FD_SET_SECTSIZE(floppy,v) { floppy.fdchar.fdc_sec_size = v; }
+
+static inline int set_parameters(int fd, struct generic_floppy_struct *floppy, 
+				 struct stat *buf)
+{
+	if (ioctl(fd, FDIOSCHAR, &(floppy->fdchar)) != 0) {
+		ioctl(fd, FDEJECT, NULL);
+		perror("");
+		return(1);
+	}
+	return 0;
+}
+#define INIT_GENERIC
 #endif /* solaris */
 
-#ifdef sunos3
+#ifdef OS_sunos3
 #define predefined_devices
 struct device devices[] = {
 	{"/dev/rfdl0c",	'A', DD312},
 	{"/dev/rfd0c",	'A', HD312},
 };
 #define INIT_NOOP
-#endif /* sunos3 */
+#endif /* OS_sunos3 */
 
-#ifdef xenix
+#ifdef OS_xenix
 #define predefined_devices
 struct device devices[] = {
 	{"/dev/fd096ds15",	'A', HD514},
@@ -286,9 +388,9 @@ struct device devices[] = {
 	{"/dev/hd0d",		'C', GENHD},
 };
 #define INIT_NOOP
-#endif /* xenix */
+#endif /* OS_xenix */
 
-#ifdef sco
+#ifdef OS_sco
 #define predefined_devices
 struct device devices[] = {
 	{ "/dev/fd0135ds18",	'A', HD312},
@@ -300,10 +402,10 @@ struct device devices[] = {
 	{ "/dev/hd0d",		'C', GENHD},
 };
 #define INIT_NOOP
-#endif /* sco */
+#endif /* OS_sco */
 
 
-#ifdef irix
+#ifdef OS_irix
 #define predefined_devices
 struct device devices[] = {
   { "/dev/rdsk/fds0d2.3.5hi",	'A', HD312},
@@ -312,17 +414,18 @@ struct device devices[] = {
   {"/dev/rdsk/fds0d2.48",	'A', DD514},
 };
 #define INIT_NOOP
-#endif /* irix */
+#endif /* OS_irix */
 
 
-#ifdef sunos4
+#ifdef OS_sunos4
 #include <sys/ioctl.h>
 #include <sun/dkio.h>
 
 #define predefined_devices
 struct device devices[] = {
 	{"/dev/rfd0c",	'A', GENFD},
-	{"/dev/rsd5c",	'D', RZIPJAZ(O_NDELAY)},
+	{"/dev/rsd4c",	'J', RZIPJAZ(O_NDELAY)},
+	{"/dev/rsd5c",	'Z', RZIPJAZ(O_NDELAY)},
 };
 
 /*
@@ -399,7 +502,7 @@ struct device devices[] = {
 #define INIT_NOOP
 #endif /* DPX1000 */
 
-#ifdef bosx
+#ifdef OS_bosx
 #define predefined_devices
 struct device devices[] = {
 	/* [block device]: DPX1000 has /dev/flbm60, DPX2 has /dev/easyfb */
@@ -410,9 +513,9 @@ struct device devices[] = {
 	{"/dev/easyfb", 'E', SSsmall},
 };
 #define INIT_NOOP
-#endif /* bosx */
+#endif /* OS_bosx */
 
-#ifdef linux
+#ifdef OS_linux
 
 #include <linux/fdreg.h>
 #include <linux/major.h>
@@ -561,8 +664,10 @@ int analyze_one_reply(RawRequest_t *raw_cmd, int *bytes, int do_print)
 struct device devices[] = {
 	{"/dev/fd0", 'A', 0, O_EXCL, 0,0, 0,DEF_ARG},
 	{"/dev/fd1", 'B', 0, O_EXCL, 0,0, 0,DEF_ARG},
-	{"/dev/sdb4",'D', GENHD },
-	{"/dev/sda4",'D', GENHD },
+	/* we assume that the Zip or Jaz drive is the second on the SCSI bus */
+	{"/dev/sdb4",'J', GENHD },
+	{"/dev/sdb4",'Z', GENHD },
+	/*	{"/dev/sda4",'D', GENHD },*/
 };
 
 /*
@@ -621,7 +726,7 @@ static inline int get_parameters(int fd, struct floppy_struct *floppy)
 
 
 /*** /jes -- for D.O.S. 486 BL DX2/80 ***/
-#ifdef freebsd
+#ifdef OS_freebsd
 #define predefined_devices
 struct device devices[] = {
 	{"/dev/rfd0.1440", 'A', HD312},
@@ -633,7 +738,7 @@ struct device devices[] = {
 #endif /* __FreeBSD__ */
  
 /*** /jes -- for ALR 486 DX4/100 ***/
-#ifdef netbsd
+#ifdef OS_netbsd
 #define predefined_devices
 struct device devices[] = {
 	{"/dev/rfd0a", 'A', HD312},
@@ -645,10 +750,10 @@ struct device devices[] = {
 	{"/dev/rwd0d", 'C', 16, 0, 0, 0, 0, 63L*512L, DEF_ARG0},
 };
 #define INIT_NOOP
-#endif /* NetBSD */
+#endif /* OS_NetBSD */
 
 
-#if (!defined(predefined_devices) && defined (m68000) && defined (sysv))
+#if (!defined(predefined_devices) && defined (CPU_m68000) && defined (OS_sysv))
 #include <sys/gdioctl.h>
 
 #define predefined_devices
@@ -691,8 +796,8 @@ int init_geom(int fd, struct device *dev, struct device *orig_dev,
 }
 #endif /* (defined (m68000) && defined (sysv))*/
 
-#ifdef __alpha
-#ifndef osf4
+#ifdef CPU_alpha
+#ifndef OS_osf4
 #ifdef __osf__
 #include <sys/fcntl.h>
 #define predefined_devices
@@ -704,7 +809,7 @@ struct device devices[] = {
 #endif
 #endif
 
-#ifdef osf
+#ifdef OS_osf
 #ifndef predefined_devices
 #define predefined_devices
 struct device devices[] = {
@@ -714,7 +819,20 @@ struct device devices[] = {
 #endif
 
 
-#if (!defined(predefined_devices) && defined(sysv4))
+#ifdef OS_nextstep
+#define predefined_devices
+#ifdef CPU_m68k
+struct device devices[] = {
+  {"/dev/rfd0b", 'A', ED312 } };
+#else
+struct device devices[] = {
+  {"/dev/rfd0b", 'A', HD312 } };
+#endif
+#define INIT_NOOP
+#endif
+
+
+#if (!defined(predefined_devices) && defined(OS_sysv4))
 #ifdef __uxp__
 #define predefined_devices
 struct device devices[] = {
