@@ -94,8 +94,9 @@ struct directory *dir_read(Stream_t *Dir,
  * on error.
  */
 
-int dir_grow(Stream_t *Dir, Stream_t *Stream, int size)
+int dir_grow(Stream_t *Dir, int size)
 {
+	Stream_t *Stream = GetFs(Dir);
 	DeclareThis(FsPublic_t);
 	int ret;
 	int buflen;
@@ -129,11 +130,10 @@ void dir_write(Stream_t *Dir, int num, struct directory *dir)
  * to a static directory structure.
  */
 
-struct directory *mk_entry(char *filename, char attr,
+struct directory *mk_entry(const char *filename, char attr,
 			   unsigned int fat, size_t size, long date,
 			   struct directory *ndir)
 {
-	int i;
 	struct tm *now;
 	time_t date2 = date;
 	unsigned char hour, min_hi, min_low, sec;
@@ -143,22 +143,22 @@ struct directory *mk_entry(char *filename, char attr,
 	strncpy(ndir->name, filename, 8);
 	strncpy(ndir->ext, filename + 8, 3);
 	ndir->attr = attr;
-	for (i = 0; i < 10; i++)
-		ndir->reserved[i] = '\0';
+	ndir->ctime_ms = 0;
 	hour = now->tm_hour << 3;
 	min_hi = now->tm_min >> 3;
 	min_low = now->tm_min << 5;
 	sec = now->tm_sec / 2;
-	ndir->time[1] = hour + min_hi;
-	ndir->time[0] = min_low + sec;
+	ndir->ctime[1] = ndir->time[1] = hour + min_hi;
+	ndir->ctime[0] = ndir->time[0] = min_low + sec;
 	year = (now->tm_year - 80) << 1;
 	month_hi = (now->tm_mon + 1) >> 3;
 	month_low = (now->tm_mon + 1) << 5;
 	day = now->tm_mday;
-	ndir->date[1] = year + month_hi;
-	ndir->date[0] = month_low + day;
+	ndir -> adate[1] = ndir->cdate[1] = ndir->date[1] = year + month_hi;
+	ndir -> adate[0] = ndir->cdate[0] = ndir->date[0] = month_low + day;
 
-	set_word(ndir->start, fat);
+	set_word(ndir->start, fat & 0xffff);
+	set_word(ndir->startHi, fat >> 16);
 	set_dword(ndir->size, size);
 	return ndir;
 }
