@@ -30,7 +30,7 @@ void mbadblocks(int argc, char **argv, int type)
 
 	init_mp(&mp);
 
-	Dir = open_subdir(&mp, argv[1], O_RDWR, 0);
+	Dir = open_subdir(&mp, argv[1], O_RDWR, 0, 0);
 	if (!Dir) {
 		fprintf(stderr,"%s: Cannot initialize drive\n", argv[0]);
 		exit(1);
