@@ -26,7 +26,7 @@ extern int errno;
 
 static void init_geometry_boot(struct bootsector *boot, struct device *dev,
 			       int sectors0, int rate_0, int rate_any,
-			       int *tot_sectors)
+			       int *tot_sectors, int keepBoot)
 {
 	int i;
 	int nb_renum;
@@ -105,14 +105,17 @@ static void init_geometry_boot(struct bootsector *boot, struct device *dev,
 			sum += boot->jump[j];/* checksum */
 		boot->ext.old.CheckSum=-sum;
 	} else {
-		boot->jump[0] = 0xeb;
-		boot->jump[1] = 0;
-		boot->jump[2] = 0x90;
-		strncpy(boot->banner, "MTOOLS33", 8);
-		/* It looks like some versions of DOS are rather picky
-		 * about this, and assume default parameters without this,
-		 * ignoring any indication about cluster size et al. */
-		set_word(boot->ext.old.BootP, OFFSET(ext.old.BootP) + 2);
+		if(!keepBoot) {
+			boot->jump[0] = 0xeb;
+			boot->jump[1] = 0;
+			boot->jump[2] = 0x90;
+			strncpy(boot->banner, "MTOOLS38", 8);
+			/* It looks like some versions of DOS are
+			 * rather picky about this, and assume default
+			 * parameters without this, ignoring any
+			 * indication about cluster size et al. */
+			set_word(boot->ext.old.BootP, OFFSET(ext.old.BootP)+2);
+		}
 	}
 	return;
 }
@@ -502,7 +505,9 @@ void mformat(int argc, char **argv, int dummy)
 	struct xdf_info info;
 #endif
 	struct bootsector *boot;
+	char *bootSector=0;
 	int c;
+	int keepBoot = 0;
 	struct device used_dev;
 	int argtracks, argheads, argsectors;
 	int tot_sectors;
@@ -539,8 +544,15 @@ void mformat(int argc, char **argv, int dummy)
 	rate_any = mtools_rate_any;
 
 	/* get command line options */
-	while ((c = getopt(argc,argv,"r:IFCc:Xt:h:s:l:n:H:M:S:12:0Aaf:"))!= EOF) {
+	while ((c = getopt(argc,argv,
+			   "B:kr:IFCc:Xt:h:s:l:n:H:M:S:12:0Aaf:"))!= EOF) {
 		switch (c) {
+			case 'k':
+				keepBoot = 1;
+				break;
+			case 'B':
+				bootSector = optarg;
+				break;
 			case 'r': 
 				Fs.dir_len = strtoul(optarg,0,0);
 				break;
@@ -718,7 +730,19 @@ void mformat(int argc, char **argv, int dummy)
 
 	/* the boot sector */
 	boot = (struct bootsector *) buf;
-	memset((char *)boot, '\0', Fs.sector_size);
+	if(bootSector) {
+		int fd;
+
+		fd = open(bootSector, O_RDONLY);
+		if(fd < 0) {
+			perror("open boot sector");
+			exit(1);
+		}
+		read(fd, buf, Fs.sector_size);
+		keepBoot = 1;
+	}
+	if(!keepBoot)
+		memset((char *)boot, '\0', Fs.sector_size);
 	set_dword(boot->nhs, used_dev.hidden);
 
 	Fs.Next = buf_init(Fs.Direct,
@@ -727,7 +751,8 @@ void mformat(int argc, char **argv, int dummy)
 			   Fs.sector_size * used_dev.heads * used_dev.sectors);
 
 	boot->nfat = Fs.num_fat = 2;
-	set_word(boot->jump + 510, 0xaa55);
+	if(!keepBoot)
+		set_word(boot->jump + 510, 0xaa55);
 	
 	/* get the parameters */
 	tot_sectors = used_dev.tracks * used_dev.heads * used_dev.sectors - 
@@ -787,7 +812,7 @@ void mformat(int argc, char **argv, int dummy)
 	set_word(boot->nrsvsect, Fs.fat_start);
 
 	init_geometry_boot(boot, &used_dev, sectors0, rate_0, rate_any,
-			   &tot_sectors);
+			   &tot_sectors, keepBoot);
 	if(Atari) {
 		boot->banner[4] = 0;
 		boot->banner[5] = random();
@@ -801,7 +826,8 @@ void mformat(int argc, char **argv, int dummy)
 		       Fs.sector_size);
 	}
 
-	inst_boot_prg(boot);
+	if(!keepBoot)
+		inst_boot_prg(boot);
 	if(dev->use_2m & 0x7f)
 		Fs.num_fat = 1;
 	zero_fat(&Fs, boot->descr);
