@@ -12,7 +12,7 @@
 #include "msdos.h"
 #include "mtools.h"
 
-#ifdef linux
+#ifdef OS_linux
 #include "patchlevel.h"
 #include <linux/fd.h>
 #include <sys/wait.h>
