@@ -1,10 +1,6 @@
 #ifndef MTOOLS_MSDOS_H
 #define MTOOLS_MSDOS_H
 
-#include <sys/types.h>
-#include <sys/stat.h>
-#include <stdio.h>
-
 /*
  * msdos common header file
  */
