@@ -129,6 +129,10 @@ extern int mtools_skip_check;
 extern int mtools_fat_compatibility;
 extern int mtools_ignore_short_case;
 extern int mtools_no_vfat;
+extern int mtools_numeric_tail;
+extern int mtools_dotted_dir;
+extern int mtools_twenty_four_hour_clock;
+extern char *mtools_date_string;
 extern int mtools_rate_0, mtools_rate_any, mtools_raw_tty;
 
 void read_config(void);
