@@ -28,7 +28,7 @@ static void bufferize(Stream_t **Dir)
 }
 	
 	
-Stream_t *descend(Stream_t *Dir, char *path, int barf,char *outname)
+Stream_t *descend(Stream_t *Dir, char *path, int barf,char *outname, int lock)
 {
 	/* this function makes its own copy of the Next pointers */
 	int entry;
@@ -48,6 +48,8 @@ Stream_t *descend(Stream_t *Dir, char *path, int barf,char *outname)
 
 	if(ret == 0){
 		SubDir = open_file(Dir, &dir);
+		if(lock)
+			LockFile(SubDir);
 		bufferize(&SubDir);
 		return SubDir;
 	}
@@ -59,6 +61,8 @@ Stream_t *descend(Stream_t *Dir, char *path, int barf,char *outname)
 	if (!strcmp(path, "..")){
 		SubDir = open_root(Dir);
 		bufferize(&SubDir);
+		if(lock)
+			LockFile(SubDir);
 		return SubDir;
 	}
 	if (barf)
@@ -72,7 +76,7 @@ Stream_t *descend(Stream_t *Dir, char *path, int barf,char *outname)
  * Descends the directory tree.  Returns 1 on error.  Attempts to optimize by
  * remembering the last path it parsed
  */
-Stream_t *subdir(Stream_t *Fs, char *pathname)
+Stream_t *subdir(Stream_t *Fs, char *pathname, int lock)
 {
 	/* this function makes its own copy of the Next pointers */
 
@@ -99,7 +103,7 @@ Stream_t *subdir(Stream_t *Fs, char *pathname)
 			terminator = *s;
 			*s = '\0';
 			if (s != tmp && strcmp(path,".") && path[0]){
-				NewDir = descend(Dir, path, 1, 0);
+				NewDir = descend(Dir, path, 1, 0, lock);
 				FREE(&Dir);
 				if(!NewDir)
 					return NewDir;
