@@ -10,7 +10,7 @@
 
 
 #include "sysincludes.h"
-#ifdef linux
+#ifdef OS_linux
 #include "msdos.h"
 #include "mtools.h"
 #include "devices.h"
@@ -601,7 +601,7 @@ Stream_t *XdfOpen(struct device *dev, char *name,
 		sprintf(errmsg,"xdf floppy: open: \"%s\"", strerror(errno));
 		goto exit_0;
 	}
-	fcntl(This->fd, F_SETFL, FD_CLOEXEC);
+	closeExec(This->fd);
 
 	This->drive = GET_DRIVE(This->fd);
 	if(This->drive < 0)
